/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
/**
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#include <config.h>
#include <bonobo/bonobo-i18n.h>
#include <gnome.h>
#include <libgnome/gnome-macros.h>
#include <string.h>

#include <gst/player/gstmediaplay.h>
#include <gst/player/gtk-playlist.h>
#include "gst-player-view.h"

BONOBO_CLASS_BOILERPLATE (GstPlayerView, gst_player_view,
    NautilusView, NAUTILUS_TYPE_VIEW)

     static void
	 gst_player_view_load_location (NautilusView * nautilus_view,
    const char *location, gpointer user_data)
{
  GstMediaPlay *mplay = user_data;
  char *filename = NULL;

  g_return_if_fail (NAUTILUS_IS_VIEW (nautilus_view));
  g_return_if_fail (location != NULL);
  g_return_if_fail (GST_IS_MEDIA_PLAY (mplay));

  nautilus_view_report_load_underway (nautilus_view);
  /* We check if location is a directory. If yes we load each file in
     the playlist. */
  filename = g_filename_from_uri (location, NULL, NULL);
  if (g_file_test (filename, G_FILE_TEST_IS_DIR)) {
    const char *local_filename = NULL;
    GDir *directory = g_dir_open (filename, 0, NULL);

    if (directory) {
      while (local_filename = g_dir_read_name (directory)) {
	char *complete_path = g_strdup_printf ("%s/%s", filename,
	    local_filename);

	if (complete_path) {
	  if (g_file_test (complete_path, G_FILE_TEST_IS_REGULAR))
	    gtk_playlist_add_mrl (GTK_PLAYLIST (mplay->playlist),
		complete_path, NULL);
	  g_free (complete_path);
	}
      }

      g_dir_close (directory);
    }
  } else if (g_file_test (filename, G_FILE_TEST_IS_REGULAR)) {
    gtk_playlist_add_mrl (GTK_PLAYLIST (mplay->playlist), location, NULL);
  }

  if (filename)
    g_free (filename);

  gst_media_play_set_location (mplay,
      gtk_playlist_get_current_mrl (GTK_PLAYLIST (mplay->playlist)));
  nautilus_view_report_load_complete (nautilus_view);
}

static void
gst_player_menu (BonoboUIComponent * ui, gpointer user_data, const char *verb)
{
  GstPlayerView *view;

  g_assert (BONOBO_IS_UI_COMPONENT (ui));
  g_assert (verb != NULL);

  view = GST_PLAYER_VIEW (user_data);

  if (strcmp (verb, "Sample Menu Item") == 0) {
  } else {
    g_assert (strcmp (verb, "Sample Dock Item") == 0);
  }
}

static void
gst_player_view_merge_bonobo_items (BonoboControl * control,
    gboolean state, gpointer user_data)
{
  GstPlayerView *view;
  BonoboUIComponent *ui_component;
  BonoboUIVerb verbs[] = {
    BONOBO_UI_VERB ("Sample Menu Item", gst_player_menu),
    BONOBO_UI_VERB ("Sample Dock Item", gst_player_menu),
    BONOBO_UI_VERB_END
  };

  g_assert (BONOBO_IS_CONTROL (control));

  view = GST_PLAYER_VIEW (user_data);

  if (state) {
    ui_component = nautilus_view_set_up_ui (NAUTILUS_VIEW (view),
	DATADIR, "gst-player-view-ui.xml", "gst-player-view");

    bonobo_ui_component_add_verb_list_with_data (ui_component, verbs, view);
  }
}

static void
gst_player_view_class_init (GstPlayerViewClass * class)
{
}

static void
gst_player_view_instance_init (GstPlayerView * view)
{
  GtkWidget *container;
  GstMediaPlay *mplay;

  mplay = gst_media_play_new ();
  gtk_widget_show (GTK_WIDGET (mplay));

  container = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_container_add (GTK_CONTAINER (container), GTK_WIDGET (mplay));
  gtk_widget_show (GTK_WIDGET (container));

  nautilus_view_construct (NAUTILUS_VIEW (view), GTK_WIDGET (container));

  g_signal_connect (view, "load_location",
      G_CALLBACK (gst_player_view_load_location), mplay);

  g_signal_connect_object (nautilus_view_get_bonobo_control
      (NAUTILUS_VIEW (view)), "activate",
      G_CALLBACK (gst_player_view_merge_bonobo_items), view, 0);
}
